===============================
pygear
===============================


.. image:: https://img.shields.io/pypi/v/pygear.svg
        :target: https://pypi.python.org/pypi/pygear

.. image:: https://img.shields.io/travis/amir-khakshour/pygear.svg
        :target: https://travis-ci.org/amir-khakshour/pygear

.. image:: https://readthedocs.org/projects/pygear/badge/?version=latest
        :target: https://pygear.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/amir-khakshour/cookiecutter-django/shield.svg
     :target: https://pyup.io/repos/github/amir-khakshour/pygear/
     :alt: Updates


PyGear is a collection of useful functions and snippets that you need or could use every day.


* Free software: GNU General Public License v3
* Documentation: https://pygear.readthedocs.io.


Features
--------

* TODO

Credits
---------



